# TDengine Python UDF

[TDengine](https://github.com/taosdata/TDengine) Python UDF enables writing UDF in Python Language.

## License

taospyudf is provided under a MIT license that can be found in the LICENSE
file. By using, distributing, or contributing to this project, you agree to the
terms and conditions of this license.

